# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-CPAN-Meta-Check
Summary:	Verify requirements in a CPAN::Meta object
Version:	0.018
Release:	1.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/CPAN-Meta-Check
Source0:	https://cpan.metacpan.org/modules/by-module/CPAN/CPAN-Meta-Check-%{version}.tar.gz
BuildArch:	noarch
# Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module
BuildRequires:	perl(base)
BuildRequires:	perl(CPAN::Meta::Prereqs) >= 2.132830
BuildRequires:	perl(CPAN::Meta::Requirements) >= 2.121
BuildRequires:	perl(Exporter)
BuildRequires:	perl(Module::Metadata) >= 1.000023
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test
BuildRequires:	perl(CPAN::Meta) >= 2.120920
BuildRequires:	perl(Env)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IPC::Open3)
BuildRequires:	perl(lib)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(Test::More) >= 0.88
# Extra tests
BuildRequires:	perl(blib)
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
This module verifies if requirements described in a CPAN::Meta object are
present.

%prep
%setup -q -n CPAN-Meta-Check-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test
make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/CPAN/
%{_mandir}/man3/CPAN::Meta::Check.3*

%changelog
* Fri Jul 21 2023 Paul Howarth <paul@city-fan.org> - 0.018-1
- Update to 0.018
  - Fix version requirement for CPAN::Meta::Prereqs
  - Move issue tracker to GitHub

* Sat Jul 15 2023 Paul Howarth <paul@city-fan.org> - 0.017-2
- Drop MODULE_COMPAT dependency from Fedora 38 onwards

* Tue Jan  3 2023 Paul Howarth <paul@city-fan.org> - 0.017-1
- Update to 0.017
  - Use Module::Metadata for more accurate testing

* Tue Jan  3 2023 Paul Howarth <paul@city-fan.org> - 0.015-1
- Update to 0.015
  - Drop Test::Deep prereq
- Use SPDX-format license tag
- Add hack to work around test issue with Scalar::Util 1.50
  (CPAN RT#145766)

* Tue Jan 12 2021 Paul Howarth <paul@city-fan.org> - 0.014-14
- Use author-independent source URL
- Use %%license unconditionally

* Tue Jun  4 2019 Paul Howarth <paul@city-fan.org> - 0.014-9
- Modernize spec
  - Switch upstream from search.cpan.org to metacpan.org
  - BR: perl-generators unconditionally
  - BR: perl-interpreter rather than perl
  - Don't explicitly clean buildroot in %%install section
  - Drop explicit %%clean section
  - Drop support for building with Test::More < 0.88
  - Drop legacy BuildRoot: and Group: tags

* Sat Nov 26 2016 Paul Howarth <paul@city-fan.org> - 0.014-1
- Update to 0.014
  - Undef versions are now passed through to CPAN::Meta::Requirements for the
    check, rather than failing with "Missing version" errors
- Update patch for building with old Test::More versions

* Thu Jul 21 2016 Paul Howarth <paul@city-fan.org> - 0.013-1
- Update to 0.013
  - Make tests more resilient against dev versions of dependencies
- BR: perl-generators where available
- Simplify find command using -delete
- Update patch for building with old Test::More versions

* Fri Jun 19 2015 Paul Howarth <paul@city-fan.org> - 0.012-1
- Update to 0.012
  - Drop dependency on Exporter 5.57

* Mon Mar 23 2015 Paul Howarth <paul@city-fan.org> - 0.011-1
- Update to 0.011
  - Declare the minimum version required for the "merged_requirements"
    interface
- Explicitly run the extra tests

* Mon Feb  2 2015 Paul Howarth <paul@city-fan.org> - 0.010-1
- Update to 0.010
  - Bump Module::Metadata prereq for $VERSION parsing (CPAN RT#101095)
  - Consistently require same version of CPAN::Meta::Requirements

* Thu Sep 11 2014 Paul Howarth <paul@city-fan.org> - 0.009-3
- Use %%license where possible

* Mon Jun 23 2014 Paul Howarth <paul@city-fan.org> - 0.009-1
- Update to 0.009
  - Various POD fixes
- Drop support for old distributions prior to FC-5
  - Drop %%defattr, redundant since rpm 4.4
  - Drop patch for building with ExtUtils::MakeMaker < 6.30

* Thu Oct 17 2013 Paul Howarth <paul@city-fan.org> - 0.008-1
- Update to 0.008
  - Switch to using merged_requirements
  - Test Env instead of Carp for version overshoot (CPAN RT#89591)
  - Document $incdirs in the right function
- Update patches as needed

* Wed Jul 31 2013 Paul Howarth <paul@city-fan.org> - 0.007-1
- Update to 0.007
  - Swap conflicts test, as underscore versions broke it (CPAN RT#87438)
- Update patches as needed

* Sat Jul 27 2013 Paul Howarth <paul@city-fan.org> - 0.006-1
- Update to 0.006
  - Fixed bad dereference during conflicts checking
- Update patches as needed

* Fri Jul 19 2013 Paul Howarth <paul@city-fan.org> - 0.005-3
- Perl 5.18 rebuild

* Sat Apr 27 2013 Paul Howarth <paul@city-fan.org> - 0.005-1
- Initial RPM version
